@@ -1,6 +1,7 @@
 from ._version import version_info  # noqa
 from ._version import __version__  # noqa
 
+from . import jupyter_server_extension
 from .widget import LayoutWidget, widgetize, run, set_jupyter_server_base_url
 from .ipython_extension import load_ipython_extension, unload_ipython_extension
 
@@ -12,6 +13,7 @@ __all__ = [
     "load_ipython_extension",
     "unload_ipython_extension",
     "set_jupyter_server_base_url",
+    "jupyter_server_extension",
 ]
 
 
@@ -60,7 +62,3 @@ def _jupyter_nbextension_paths():
             "require": "idom-client-jupyter/extension",
         }
     ]
-
-
-def _jupyter_server_extension_paths():
-    return [{"module": "idom_jupyter.jupyter_server_extension"}]
