@@ -1,7 +1,8 @@
 from functools import partial
 
-from idom.core.component import AbstractComponent
+from idom.core.component import Component
 from IPython import get_ipython
+from IPython.core.interactiveshell import InteractiveShell
 from IPython.display import display
 
 from .widget import LayoutWidget
@@ -11,13 +12,13 @@ _EXTENSION_LOADED = False
 _POST_RUN_CELL_HOOK = None
 
 
-def load_ipython_extension(ipython):
+def load_ipython_extension(ipython: InteractiveShell) -> None:
     global _POST_RUN_CELL_HOOK, _EXTENSION_LOADED
     if not _EXTENSION_LOADED:
         _POST_RUN_CELL_HOOK = partial(_post_run_cell, ipython)
         ipython.events.register("post_run_cell", _POST_RUN_CELL_HOOK)
         ipython.display_formatter.ipython_display_formatter.for_type(
-            AbstractComponent, lambda element: ({}, {})
+            Component, lambda component: ({}, {})
         )
         _EXTENSION_LOADED = True
 
@@ -29,8 +30,8 @@ def unload_ipython_extension(ipython):
     _EXTENSION_LOADED = False
 
 
-def _post_run_cell(ipython, result):
-    if isinstance(result.result, AbstractComponent):
+def _post_run_cell(ipython: InteractiveShell, result):
+    if isinstance(result.result, Component):
         display(LayoutWidget(result.result))
 
 
